@@ -15,5 +15,6 @@ INSTALLER_LANG="EN"
 
 SCRIPT_DIR=$(cd $(dirname $0);pwd)
 
-DATA_SCRIPT="${SCRIPT_DIR}/scripts/cloud_data_maint_EN.sh INSERT"
+#DATA_SCRIPT="${SCRIPT_DIR}/scripts/cloud_data_maint_EN.sh INSERT"
+DATA_SCRIPT="${SCRIPT_DIR}/scripts/aws_option_install_data_EN.sql"
 . ${SCRIPT_DIR}/scripts/cloud_option_install_main.sh
\ No newline at end of file
