@@ -649,8 +649,8 @@ public interface IResourceManagement {
 	void disconnect();
 	
 // インスタンス
-	Instance createInstance(String name,  String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault;
-	Instance restoreInstance(String instanceBackupId, String name,  String flavor, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault;
+	Instance createInstance(String id, String name,  String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault;
+	Instance restoreInstance(String facilityId, String instanceBackupId, String name,  String flavor, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault;
 	void deleteInstance(String instanceId) throws CloudManagerFault;
 	Instance getInstance(String instanceId) throws CloudManagerFault;
 	List<Instance> getInstances(String...instanceIds) throws CloudManagerFault;
