@@ -180,7 +180,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 	}
 
 	@Override
-	public Instance createInstance(String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
+	public Instance createInstance(String id, String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
 		AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
 		com.amazonaws.services.ec2.model.Instance awsInstance = null;
 		boolean success = false;
@@ -1104,7 +1104,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 	}
 
 	@Override
-	public Instance restoreInstance(String instanceBackupId, String name, String flavor, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
+	public Instance restoreInstance(String facilityId, String instanceBackupId, String name, String flavor, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
 		try {
 			String value = store.get(RT_InstanceBackup, instanceBackupId);
 
@@ -1161,7 +1161,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 
 			String backupedDetail = om.writerWithType(InstanceDetail.class).writeValueAsString(backuped.instanceDetail);
 
-			return createInstance(backuped.name, backuped.flavor, instanceBackupId, backuped.zone, backupedDetail, backuped.tags);
+			return createInstance(facilityId, backuped.name, backuped.flavor, instanceBackupId, backuped.zone, backupedDetail, backuped.tags);
 		}
 		catch (Exception e) {
 			throw new InternalManagerError(e);
