@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2013 NTT DATA Corporation
+Copyright (C) 2014 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
@@ -32,7 +32,6 @@ import com.clustercontrol.cloud.bean.CreateAccountResourceRequest;
 import com.clustercontrol.cloud.bean.CreateCloudUserRequest;
 import com.clustercontrol.cloud.bean.ModifyAccountBillingDetailRequest;
 import com.clustercontrol.cloud.bean.ModifyAccountResourceRequest;
-import com.clustercontrol.cloud.commons.CloudConstants;
 import com.clustercontrol.cloud.dao.CloudAccountResourceDao;
 import com.clustercontrol.cloud.dao.CloudUserDao;
 import com.clustercontrol.cloud.persistence.EntityManagerEx;
@@ -139,7 +138,7 @@ public class AccountResourceOperator implements IAccountResourceOperator {
 			throw ErrorCode.ACCOUNTRESOURCE_INVALID_ACCOUNTRESOURCE_NOT_FOUND.cloudManagerFault(accountResourceId);
 		}
 		
-		try (RemovedEventNotifier<CloudAccountResource> notifier = new RemovedEventNotifier<>(CloudConstants.Node_AccountResource, CloudAccountResource.class, new CloudAccountResource(dao))) {
+		try (RemovedEventNotifier<CloudAccountResource> notifier = new RemovedEventNotifier<>(null, CloudAccountResource.class, new CloudAccountResource(dao))) {
 			em.remove(dao);
 			AccountResourceUtil.removeAccountResourceHierarchy(RepositoryControllerBeanWrapper.bean(), accountResourceId);
 			notifier.setCompleted();
@@ -149,13 +148,12 @@ public class AccountResourceOperator implements IAccountResourceOperator {
 	@Override
 	@Transactional(Transactional.TransactionType.Supported)
 	public CloudAccountResource findCloudAccountResource(String accountResourceId) throws CloudManagerFault {
-		try {
-			EntityManagerEx em = SessionService.current().getEntityManagerEx();
-			return new CloudAccountResource(em.find(CloudAccountResourceDao.class, accountResourceId));
-		}
-		catch (NoResultException e) {
+		EntityManagerEx em = SessionService.current().getEntityManagerEx();
+		CloudAccountResourceDao dao = em.find(CloudAccountResourceDao.class, accountResourceId);
+		if (dao == null) {
 			throw ErrorCode.ACCOUNTRESOURCE_INVALID_ACCOUNTRESOURCE_NOT_FOUND.cloudManagerFault(accountResourceId);
 		}
+		return new CloudAccountResource(dao);
 	}
 
 	@Override
